@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,13 +33,15 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.tpu_v2alpha1.services.tpu import pagers
-from google.cloud.tpu_v2alpha1.types import cloud_tpu
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import TpuTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
+
+from google.cloud.tpu_v2alpha1.services.tpu import pagers
+from google.cloud.tpu_v2alpha1.types import cloud_tpu
+
 from .client import TpuClient
+from .transports.base import DEFAULT_CLIENT_INFO, TpuTransport
+from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
 
 
 class TpuAsyncClient:
@@ -217,9 +219,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_list_nodes():
+            async def sample_list_nodes():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.ListNodesRequest(
@@ -230,7 +232,7 @@ class TpuAsyncClient:
                 page_result = client.list_nodes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -289,12 +291,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListNodesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -315,9 +325,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_get_node():
+            async def sample_get_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.GetNodeRequest(
@@ -325,7 +335,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_node(request=request)
+                response = await client.get_node(request=request)
 
                 # Handle the response
                 print(response)
@@ -381,7 +391,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -403,9 +418,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_create_node():
+            async def sample_create_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 node = tpu_v2alpha1.Node()
@@ -422,7 +437,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -497,7 +512,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -525,9 +545,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_delete_node():
+            async def sample_delete_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.DeleteNodeRequest(
@@ -539,7 +559,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -600,7 +620,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -624,14 +649,13 @@ class TpuAsyncClient:
         r"""Stops a node. This operation is only available with
         single TPU nodes.
 
-
         .. code-block:: python
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_stop_node():
+            async def sample_stop_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.StopNodeRequest(
@@ -642,7 +666,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -684,7 +708,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -711,9 +740,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_start_node():
+            async def sample_start_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.StartNodeRequest(
@@ -724,7 +753,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -766,7 +795,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -795,9 +829,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_update_node():
+            async def sample_update_node():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 node = tpu_v2alpha1.Node()
@@ -813,7 +847,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -887,7 +921,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -911,14 +950,13 @@ class TpuAsyncClient:
         r"""Generates the Cloud TPU service identity for the
         project.
 
-
         .. code-block:: python
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_generate_service_identity():
+            async def sample_generate_service_identity():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.GenerateServiceIdentityRequest(
@@ -926,7 +964,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.generate_service_identity(request=request)
+                response = await client.generate_service_identity(request=request)
 
                 # Handle the response
                 print(response)
@@ -965,7 +1003,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -985,9 +1028,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_list_accelerator_types():
+            async def sample_list_accelerator_types():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.ListAcceleratorTypesRequest(
@@ -998,7 +1041,7 @@ class TpuAsyncClient:
                 page_result = client.list_accelerator_types(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1057,12 +1100,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAcceleratorTypesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1083,9 +1134,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_get_accelerator_type():
+            async def sample_get_accelerator_type():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.GetAcceleratorTypeRequest(
@@ -1093,7 +1144,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_accelerator_type(request=request)
+                response = await client.get_accelerator_type(request=request)
 
                 # Handle the response
                 print(response)
@@ -1151,7 +1202,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1171,9 +1227,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_list_runtime_versions():
+            async def sample_list_runtime_versions():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.ListRuntimeVersionsRequest(
@@ -1184,7 +1240,7 @@ class TpuAsyncClient:
                 page_result = client.list_runtime_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1243,12 +1299,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListRuntimeVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1269,9 +1333,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_get_runtime_version():
+            async def sample_get_runtime_version():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.GetRuntimeVersionRequest(
@@ -1279,7 +1343,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_runtime_version(request=request)
+                response = await client.get_runtime_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1337,7 +1401,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1356,9 +1425,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v2alpha1
 
-            def sample_get_guest_attributes():
+            async def sample_get_guest_attributes():
                 # Create a client
-                client = tpu_v2alpha1.TpuClient()
+                client = tpu_v2alpha1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v2alpha1.GetGuestAttributesRequest(
@@ -1366,7 +1435,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_guest_attributes(request=request)
+                response = await client.get_guest_attributes(request=request)
 
                 # Handle the response
                 print(response)
@@ -1405,7 +1474,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1419,7 +1493,9 @@ class TpuAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-tpu",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-tpu",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
